@@ -162,17 +162,17 @@ class Scheduler(Process):
         except Exception as ex:
             raise ex
 
-        if cmd_out != "Job {}.0 marked for removal".format(self.cluster_id):
+        if str(cmd_out) != "'Job {}.0 marked for removal'\\n".format(self.cluster_id):
             raise Exception("Failed to hold job for scheduler: %s" % cmd_out)
 
         await super().close()
 
 
 class RemoteHTCondor(SpecCluster):
-    def __init__(self, asynchronous=True):
+    def __init__(self, asynchronous=False):
         sched = {"cls": Scheduler, "options": {}}
         super().__init__(
-            scheduler=sched, asynchronous=True, workers={}, name="RemoteHTC"
+            scheduler=sched, asynchronous=asynchronous, workers={}, name="RemoteHTC"
         )
 
 
